<h1>
  <img src="https://github.com/kdqed/zaturn/raw/main/zaturn/studio/static/logo.png" width="24" height="24">
  <span>Zaturn: Your Co-Pilot For Data Analytics & Business Insights</span>
</h1>

## Just Chat With Your Data! No SQL, No Python.

Zaturn provides tools that enable AI models to run SQL, so you don't have to. It can be used as an MCP or as a web interface similar to Jupyter Notebook.

## Zaturn in Action

https://github.com/user-attachments/assets/d42dc433-e5ec-4b3e-bef0-5cfc097396ab

## Features:

### Multiple Data Sources 

Zaturn can currently connect to the following data sources: 
- SQL Databases: PostgreSQL, SQLite, DuckDB, MySQL, ClickHouse, SQL Server, BigQuery
- Files: CSV, Parquet

[Request data source by raising an issue](https://github.com/kdqed/zaturn/issues/new)

### Visualizations

In addition to providing tabular and textual summaries, Zaturn can also generate the following image visualizations

- Scatter and Line Plots
- Histograms
- Strip and Box Plots
- Bar Plots
- Density Heatmap (aka. 2D Histograms)
- Polar Scatter and Line Plots

[Request visualizations by raising an issue](https://github.com/kdqed/zaturn/issues/new)


## Installation & Setup

See [https://zaturn.pro/docs/install](https://zaturn.pro/docs/install)


## Roadmap

- Support for more data source types & more data visualizations as per community requests
- Dashboard building: Pin queries and visuals to re-run without LLM calls.
- Multi-user capabilities
- Predictive Analytics and ML features


## Help And Feedback

[Raise an issue](https://github.com/kdqed/zaturn/issues)

## Support The Project

If you find Zaturn useful, please support this project by:
- Starring the project
- Sponsoring the development
- Spreading the word

Your support will enable me to dedicate more of my time to Zaturn.

## Example Dataset Credits

The [pokemon dataset compiled by Sarah Taha and PokéAPI](https://www.kaggle.com/datasets/sarahtaha/1025-pokemon) has been included under the [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/) license for demonstration purposes.

## Featured on glama.ai

<a href="https://glama.ai/mcp/servers/@kdqed/zaturn">
  <img width="380" height="200" src="https://glama.ai/mcp/servers/@kdqed/zaturn/badge" alt="Zaturn MCP server" />
</a>


## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=kdqed/zaturn&type=Date)](https://www.star-history.com/#kdqed/zaturn&Date)
